function [raydata,intensity,error,vigcode] = zray(f,r,s,w,c,mode)
% ZRAY gets raytrace data from ZEMAX
% function [raydata,intensity,error,vigcode] = zray(f,r,s,w,c,mode);
% INPUT:    f = field number, or [hx hy] normalized field coordinates, 
%               default = [0 0]
%           r = normalized pupil coordinates, default = [0 0]
%           s = surface, default = all, 1:image
%           w = wavelength, default wavelength number = 1
%           mode, real (0) or paraxial (1), default = 0
% OUTPUT:   raydata = [x y z l m n sl sm sn]'
%               x y z, coords at surface
%               l m n, direction cosines at surface
%               sl sm sn, direction cosines of surface normal at intercept
%           intensity, relative value including pupil or surface
%                       apodization
%           error,  flag=0 if successful raytrace, >0 for vignetting at
%                   flag>0 indicates vignetting at that surface
%                   flag<0 indicates TIR at that surface                
%           vigcode, first surface where ray was vignetted

if nargin<1, f=[0 0]; end
if nargin<2, r=[0 0]; end
if nargin<3, s=1:zims; end %image surface
if nargin<4, w=1; end
if nargin<5, c=1; end
if nargin<6, mode=0; end %default to real raytrace

%set configuration
zc(c);

%find relative field coords if field number is input
if length(f)==1, 
    f0 = zf; %get field data
    r0 = f0(:,1).*f0(:,1) + f0(:,2).*f0(:,2); %vector of radial field squared
    [rmax,fmax] = max(r0); %find the max
    f0(:,1) = f0(:,1)/f0(fmax,1);%normalize x
    f0(:,2) = f0(:,2)/f0(fmax,2);%normalize y
    f = f0(f,:); %select field coords
    f(isnan(f))=0;
end

%get ray data
for i=1:length(s)
    cmd = ['GetTrace,' num2str(w) ',' num2str(mode) ',' num2str(s(i)) ',' ...
        num2str(f(1)) ',' num2str(f(2)) ',' num2str(r(1)) ',' num2str(r(2))];
    [error(i),vigcode(i),x(i),y(i),z(i),l(i),m(i),n(i),sl(i),sm(i),sn(i),intensity(i)] = ...
        strread(zreq(cmd),'%d%d%f%f%f%f%f%f%f%f%f%f','delimiter',',');
end
raydata = [x' y' z' l' m' n' sl' sm' sn'];

%default output
if nargout<1
   disp('  Surf #   X     Y     Z     L     M     N    SL    SM    SN');
   disp([s' raydata]);
end

% Copyright  2005 United States Government as represented by the Administrator 
% of the National Aeronautics and Space Administration.  No copyright is claimed 
% in the United States under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     